#[repr(u8)]pub enum ThreadState {
Ready = 0,
Running = 1,
Parked = 2,
NearlyParked = 3,
Killed(isize),
}Available on crate feature
full only.Variants
Ready = 0
The thread is able to run, but has not yet been scheduled
Running = 1
The thread is actively running
Parked = 2
The thread is parked
NearlyParked = 3
The thread is in the process of being parked